from django.utils.translation import ugettext as _

from jmb.ticket import utils

def get_ticket_fieldsets(user=None, obj=None, *args, **kwargs):
    # defines fieldsets in function of ticket_role
    user, contact = utils.get_current_contact(user)
    if contact:
        if obj:
            role = contact.get_role(obj.organization, obj.project)
        else:
            role = 'manager' if contact.is_owner() else 'customer'
    elif user.is_superuser:
        role = "manager"
    else:
        return ()
    ## MANAGER
    fieldsets_manager = (
        (_('Additional Information'), {
            'classes': ('collapse',),
            'fields': (
                ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
            )
        }),
        (_('General Information'), {
            'fields': (
                ('title', 'priority', ),
                ('organization', 'project',),
                ('address',),
                ('category', 'typology',),
                ('status', 'progress_status'),
                ('submitter', 'assigned_by'),
                ('assigned_to', 'to_be_planned'),
                'description',
                ('keywords', 'public'),
                ('triggerline', 'deadline'),
                'duration',
            )
        }),
        (_('Additional Information'), {
            'classes': ('collapse',),
            'fields': (
                ('note',),
                ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
            )
        }),
    )

    ## STAFF
    fieldsets_staff = (
        (_('Additional Information'), {
            'classes': ('collapse',),
            'fields': (
                ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
            )
        }),
        (_('General Information'), {
            'fields': (
                ('title', 'priority', ),
                ('organization', 'project'),
                ('address',),
                ('category', 'typology',),
                ('status', 'progress_status'),
                ('submitter', 'to_be_planned', ),
                ('assigned_by', 'assigned_to', ),
                'description',
                ('keywords', 'public'),
                ('triggerline', 'deadline'),
                'duration',
            )
        }),
        (_('Note'), {
            'classes': ('collapse',),
            'fields': (('note',),)
        }),
    )

    ## CUSTOMER
    fieldsets_customer = (
        (_('Additional Information'), {
            'classes': ('collapse',),
            'fields': (
                ('date_create', 'date_last_modify', 'creator', 'last_modifier',)
            )
        }),
        (_('General Information'), {
            'fields': (
                ('title', 'priority', ),
                ('organization', 'project'),
                ('category', 'typology',),
                ('status', 'progress_status'),
                ('submitter', 'assigned_by'),
                ('assigned_to', ),
                'description',
                ('keywords', 'duration'),
                ('triggerline', 'deadline'),
            )
        }),
        (_('Note'), {
            'classes': ('collapse',),
            'fields': (('note',),)
        }),
    )
    #return fieldsets_manager
    if role == 'manager':
        return fieldsets_manager
    if role == 'staff':
        return fieldsets_staff
    else:
        return fieldsets_customer

def get_ticket_list_display(*args, **kwargs):
    ## MANAGER
    list_display_manager = (
        'id', 'public', 'status', 'get_ticket_priority_icon',
        'get_date_create', 'triggerline', 'get_deadline', 'get_title',
        'get_zip_code', 'get_address', 'organization',
        'assigned_by', 'get_string_assigned_to', 'submitter',
        'get_num_assistances', 'get_num_comments',
        'get_edit_icon_iframe', 'get_add_plan', 'get_delete_icon'
    )

    ## STAFF
    list_display_staff = (
        'id', 'public', 'status', 'get_date_create', 'triggerline', 'deadline',
        'get_title', 'get_num_comments', 'get_edit_icon', 'get_delete_icon'
    )

    ## CUSTOMER
    list_display_customer = (
        'id', 'status', 'get_date_create', 'triggerline', 'deadline',
        'get_title', 'get_num_comments', 'get_edit_icon', 'get_delete_icon'
    )
    return list_display_manager

def get_readonly_fields(user=None, obj=None, *args, **kwargs):
    if not obj:
        return ()

    user, contact = utils.get_current_contact(user)
    if contact:
        if obj:
            role = contact.get_role(obj.organization, obj.project)
        else:
            role = 'manager' if contact.is_owner() else 'staff'

    elif user.is_superuser:
        role = "manager"
    else:
        return ()
    ## MANAGER
    if role == "manager":
        return ()

    ## STAFF
    if role == "staff":
        return (
            'status', 'category', 'typology',
            'submitter', 'assigned_by', 'assigned_to',
            'duration',
        )

    ## CUSTOMER
    if role == "customer":
        return (
            'status', 'public',
            'submitter', 'assigned_by', 'assigned_to',
            'duration',
        )

    return ()

def get_advanced_search_fields(*args, **kwargs):

    ## MANAGER
    advanced_search_fields = (
        ('id', 'title__icontains', 'description__icontains',),
        ('project__name__icontains:project', 'organization__name__icontains:organization',
         'project__organization__addresses__zip_code',),
        ('status__in', 'progress_status__in:progress', 'keywords',),
        ('priority__in', 'typology__in', 'category__in',),
        ('date_create__gte', 'date_create__lte',),
        ('triggerline__gte', 'triggerline__lte',),
        ('deadline__gte', 'deadline__lte',),
    )
    return advanced_search_fields
