# -*- coding: utf-8 -*-
import os
import datetime
import email
import json
import uuid
from bs4 import BeautifulSoup
from email.header import decode_header
from icalendar import Calendar, Event, vText, vCalAddress

from django.conf import settings
from django import forms
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext as _
from django.contrib import admin
from django.core.exceptions import ObjectDoesNotExist
from django.http import HttpResponse, Http404, HttpResponseRedirect, HttpResponseForbidden
from django.template.response import TemplateResponse
from django.core import serializers
from django.contrib.admin.utils import unquote
from django.contrib import messages

from django.db.models import Q
from django.core.mail.message import EmailMessage
from django.core.files.base import ContentFile
from django.core.files import File
from django.conf import settings
from django.core.mail.backends.smtp import EmailBackend
from django.core import mail

from jmb.core.shortcuts import render_to_string
from jmb.jadmin import JumboModelAdmin
from jmb.core.middleware.thread_local import get_current_user
from jmb.jadmin import AjaxInline, ConstrainedModelForm, register_inline
from jmb.organization.models import Organization, Contact
from jmb.ticket import models
from jmb.ticket import views as ticket_views
from jmb.ticket import utils
import forms as ticket_forms

###### Actions
def create_pdf(model_admin, request, queryset):
    from PyPDF2 import PdfFileMerger

    merger = PdfFileMerger()
    for obj in queryset.all():
        merger.append(obj.get_report())
#        merger.append(open(obj.get_report()))
#    merger.write(open('%s/report.pdf' % settings.MEDIA_ROOT, 'wb'))
    merger.write(open('/tmp/report.pdf', 'wb'))

    response = HttpResponse(content_type='application/pdf')
    response['Content-Disposition'] = 'attachment; filename=report.pdf'
    response.write(open('/tmp/report.pdf').read())
    return response

create_pdf.short_description = _('Generate pdf')


class PlanAjaxInline(AjaxInline):
    model = models.Plan
    fk_name = 'ticket'
    list_display = ('description', 'date_begin', 'date_end', 'get_workers',
                    'get_edit_icon_iframe', 'get_delete_icon_iframe')

class PlanAdmin(JumboModelAdmin):

    class Media:
        js = ("ticket/js/wrapiframe.js",)

    save_as = True
    list_display = (
        'get_ticket_priority_icon', 'get_ticket_description', 'description', 'date_begin',
        'date_end', 'get_workers', 'get_pdf',
        'get_edit_icon', 'get_delete_icon'
    )
    list_display_csv = (
        'get_address', 'get_client', 'description', 'date_end',
    )
    search_fields = (
        'ticket__title', 'ticket__description', 'description',
        'ticket__project__organization__addresses__name',
        'ticket__project__organization__addresses__zip_code',
    )
    advanced_search_fields = (
        ('ticket__title__icontains:ticket', 'workers__last_name__icontains',
         'workers__first_name__icontains'),
        ('ticket__category__in', 'ticket__typology__in', 'ticket__priority__in'),
        ('ticket__description__icontains', 'description__icontains',
         'ticket__project__organization__addresses__name__icontains:indirizzo',),
        ('status', 'ticket__project__organization__addresses__zip_code:cap',),
        ('date_begin__gte', 'date_end__lte', 'date_begin__range'),
    )
    form = ticket_forms.PlanAdminForm
    fieldsets = (
        (_('general admin'), {'fields': (
            'ticket',
            ('date_begin', 'date_end'),
            'workers',
            'description',
            ('address', 'priority'),
            ('status', 'close_ticket')
        )}),
    )

    actions = [create_pdf]

    def get_client(self, obj):
        return obj.ticket.organization.name
    get_client.short_description = _('Client')

    def get_ticket_description(self, obj):
        return "%s<br>%s" % (obj.ticket.label(), obj.ticket.label_description())
    get_ticket_description.short_description = 'Ticket'
    get_ticket_description.allow_tags = True

    def get_ticket_priority_icon(self, obj):
        priority = obj.priority or obj.ticket.priority

        return """<div title='%(name)s' style='font-weight:bold;
                color:%(color)s;' class='prioritydiv' >%(id)s</div>""" % {
            'name': priority.name,
            'color': priority.color,
            'textcolor': priority.color_text,
            'id': priority.priority
        }

    get_ticket_priority_icon.allow_tags = True
    get_ticket_priority_icon.short_description = _("P")
    get_ticket_priority_icon.admin_order_field = 'priority'

    def get_pdf(self, obj):
        opts = self.model._meta
        return '''<a class="wrapiframe" target="_blank" href="%(reverse_url_pdf)s" alt="pdf">
                     <img src="%(static_url)sjmb/images/pdf_icon.png"/>
            </a>''' % {
            'reverse_url_pdf': reverse(
                'admin:%s_%s_pdf' % (opts.app_label, opts.object_name.lower()), args=(obj.id,)
            ),
            'static_url': settings.STATIC_URL,
        }
    get_pdf.short_description = _("PDF")
    get_pdf.allow_tags = True

    def get_workers(self, obj):
        return "<br>".join(str(w) for w in obj.workers.all())
    get_workers.short_description = _('workers')
    get_workers.allow_tags = True

    def get_urls(self):

        from django.conf.urls import patterns, url
        urls = super(PlanAdmin, self).get_urls()
        my_urls = [
            url(
                r'^iframe/(?P<object_id>\d+)/(?P<method>\w+)/$',
                self.iframe,
                name='ticket_plan_iframe'
            ),
            url(
                r'^only_result_list/$',
                self.only_result_list_view,
                name='ticket_plan_only_result_list'
            ),
            url(
                r'^pdf/(?P<object_id>\d+)/$',
                self.pdf_view,
                name='ticket_plan_pdf'
            ),
            url(
                r'^pdfviewer/$',
                self.pdf_viewer,
                name='ticket_plan_pdfviewer'
            ),
            url(
                r'^invitation/(?P<object_id>\d+)/$',
                self.send_invitation_view,
                name='ticket_plan_invitation'
            ),
            url(
                r'^plans/$',
                self.get_plans_detail,
                name='get_plans_detail'
        )
        ]
        return my_urls + urls

    def get_plans_detail(self, request):
        opts = self.model._meta
        app_label = opts.app_label
        ids = request.GET.getlist('id', [])
        is_popup = bool(int(request.GET.get('_popup', 0)))
        if not isinstance(ids, list):
            ids = [ids]
        plans = models.Plan.objects.filter(ticket__project__id__in=ids).order_by('date_begin')
        return TemplateResponse(request, 'admin/%s/%s/plans_details.html' % (app_label,
                                                                             opts.object_name.lower()),
                                {"plans": plans, 'is_popup': is_popup}, status=200)

    # vede e stampa subito il pdf
    # :pdf passare come parametro get il link assoluto del pdf
    # se il parametro non viene passato restituisce 404
    # docs: http://mozilla.github.io/pdf.js/
    def pdf_viewer(self, request):
        opts = self.model._meta
        app_label = opts.app_label
        pdfurl = request.GET.get('pdf', False)
        if not pdfurl:
            raise Http404
        return TemplateResponse(request, 'admin/%s/pdfviewer.html' % app_label,
                                {'pdf': pdfurl})

    def iframe(self, request, object_id, method):
        qs = super(PlanAdmin, self).get_queryset(request).filter(id=object_id)
        data_json = serializers.serialize(
            "json", qs.all(), extras=('label', 'label_description'), use_natural_keys=True)
        return TemplateResponse(request, 'admin/ticket/iframe_callback.html',
                                {"data_json": data_json, "method": method}, status=200)

    def send_invitation_view(self, request, object_id):
        # vedi http://tools.ietf.org/html/rfc2446#section-3.2.2
        opts = self.model._meta
        app_label = opts.app_label

        if (request.method == "POST"):
            form = ticket_forms.InvitationForm(request.POST, object_id=object_id)
            if form.is_valid():
                try:
                    form.send(object_id)
                except Exception, e:
                    messages.error(request, str(e))
                    raise
                else:
                    messages.success(request, _("Invitation Sent"))

                return TemplateResponse(
                    request, 'admin/ticket/plan/invitation_form.html',
                    {'form': form, 'is_popup': True})
        else:
            form = ticket_forms.InvitationForm(object_id=object_id)
        return TemplateResponse(request, 'admin/%s/%s/invitation_form.html' % (app_label,
                                                                               opts.object_name.lower()), {'form': form, 'is_popup': True})

    def send_invitation_old_ok(self, request, object_id):
        # vedi http://tools.ietf.org/html/rfc2446#section-3.2.2
        opts = self.model._meta
        app_label = opts.app_label

        if (request.method == "POST"):
            form = ticket_forms.InvitationForm(request.POST, object_id=object_id)
            if form.is_valid():
                cd = form.cleaned_data

                contacts = Contact.objects.filter(
                    Q(id__in=cd['workers']) | Q(id__in=cd['contacts']))
                contacts_email = [contact.email for contact in contacts]
                recipient_list = contacts_email + cd['emails']
                recipient_list = set(recipient_list)

                plan = models.Plan.objects.get(id=object_id)
                cal = Calendar()
                event = Event()

                summary = "%s %s" % (plan.description, plan.ticket.description)
                address = plan.ticket.organization.get_first_address()
                title = _('Invitation Appointment: %s') % BeautifulSoup(plan.ticket.title).getText()
                if address:
                    event['location'] = vText(address)

                event.add('method', 'REQUEST')
                event.add('summary', summary)
                event.add('dtstart', plan.date_begin)
                event.add('dtend', plan.date_end)
                event.add('uid', uuid.uuid1().hex)
                event.add('status', 'CONFIRMED')
                event.add('sequence', 0)
                event.add('version', '2.0')
                event.add('PRODID', 'Jumbo Ticket platform')

                for recipient in recipient_list:
                    attendee = vCalAddress('MAILTO:%s' % recipient)
                    attendee.params['CN'] = recipient
                    attendee.params['ROLE'] = vText('REQ-PARTICIPANT')
                    event.add('attendee', attendee, encode=0)

                from_email = settings.TICKET_ICS_DEFAULT_SENDER
                user, contact = utils.get_current_contact()
                if contact:
                    if contact.email:
                        organizer = vCalAddress('MAILTO:%s' % contact.email)
                        from_email = '%s %s' % (contact.get_full_name(), 'contact.email')
                    else:
                        organizer = vCalAddress('MAILTO:%s' % settings.TICKET_ICS_DEFAULT_SENDER)

                    organizer.params['cn'] = vText(contact.get_full_name() + " "
                                                   + contact.organization.name)
                    organizer.params['role'] = vText(contact.organization.name)
                    event['organizer'] = organizer

                cal.add_component(event)

                msg = EmailMessage(title, summary, from_email, recipient_list)
                msg.content_subtype = "html"

                filename = "meeting.ics"
                part = email.MIMEBase.MIMEBase('text', "calendar", method="REQUEST", name=filename)
                part.set_payload(cal.to_ical())
                email.Encoders.encode_base64(part)
                part.add_header('Content-Description', filename)
                part.add_header("Content-class", "urn:content-classes:calendarmessage")
                part.add_header("Filename", filename)
                part.add_header("Path", filename)
                msg.attach(part)

                try:
                    msg.send()
                except Exception, e:
                    messages.error(request, str(e))
                # else:
                #      messages.success(request, _("Invitation Sent to %s") % ", ".join(recipient_list))

                return TemplateResponse(request, 'admin/%s/%s/invitation_form.html' % (app_label,
                                                                                       opts.object_name.lower()), {'form': form, 'is_popup': True})
        else:
            form = ticket_forms.InvitationForm(object_id=object_id)
        return TemplateResponse(request, 'admin/%s/%s/invitation_form.html' % (app_label,
                                                                               opts.object_name.lower()), {'form': form, 'is_popup': True})

    def pdf_view(self, request, object_id):
        """
        return an HttpResponse object instance with a PDF file as attachment
        """
        obj = self.get_object(request, unquote(object_id))
        if obj:
            plan_description = obj.label()
        else:
            plan_description = ""
        file_type = 'pdf'
        filename = obj.get_report()
        file_pdf = open(filename, "r")
        response = HttpResponse(content_type='application/pdf')
        response['Content-Disposition'] = 'attachment; filename=report.pdf'
        response.write(file_pdf.read())
        file_pdf.close()
        os.unlink(filename)
        return response

    def change_view(self, request, object_id, form_url='', extra_context=None):

        opts = self.model._meta
        app_label = opts.app_label

        self.change_form_template = [
            'admin/%s/%s/change_form.hutml' % (app_label, opts.object_name.lower()),
            'admin/%s/change_form.html' % app_label,
            'admin/change_form.html'
        ]

        if request.method == 'POST':
            json_param = request.GET.get('json', False)
            if json_param:
                try:
                    request_dict = json.loads(request.body)
                    instance = models.Plan.objects.get(id=object_id)
                except ValueError:
                    return HttpResponse('Invalid Request', status=400)
                except ObjectDoesNotExist:
                    raise Http404

                form = PlanAdmin.form(request_dict, instance=instance)
                if form.is_valid():
                    item = form.save()
                    json_data = serializers.serialize("json", [instance, ], extras=('label',))
                    return HttpResponse(json_data, content_type="application/json",
                                        status=200)
                else:
                    return HttpResponse(form.errors.items(), status=400)

            jpopup_param = request.GET.get('jpopup', False)
            if jpopup_param:
                extra_context = extra_context or {}
                extra_context['is_popup'] = True
                self.change_form_template = 'admin/ticket/change_form_iframe.html'
                response = super(PlanAdmin, self).change_view(
                    request, object_id, form_url, extra_context)

            _json = request.POST.get('_json', False)
            _json_continue = request.POST.get('_json_continue', False)
            if _json or _json_continue:
                extra_context = extra_context or {}
                method = '_json_continue' if _json_continue else '_json'
                response = super(PlanAdmin, self).change_view(
                    request, object_id, form_url, extra_context)
                response['location'] = reverse('admin:ticket_plan_iframe', args=[object_id, method])

            if request.POST.get('closeticket', False):
                ticket = models.Plan.objects.get(id=object_id).ticket
                ticket.status = 0
                ticket.save

            try:
                return response
            except UnboundLocalError:
                return super(PlanAdmin, self).change_view(
                    request, object_id, form_url, extra_context)

        if request.method == 'GET':

            json_param = request.GET.get('json', False)
            jpopup_param = request.GET.get('jpopup', False)

            if json_param:
                qs = super(PlanAdmin, self).get_queryset(request).filter(id=object_id)
                qs = qs.prefetch_related('workers', 'workers__role',
                                         'ticket__project_organization__address')
                qs = qs.select_related(
                    'ticket',
                    'priority',
                    'address',
                    'ticket__project__organization'
                )
                data = serializers.serialize("json", qs.all(), extras=(
                    'label',), use_natural_keys=True)
                return HttpResponse(data, content_type="application/json")
            if jpopup_param:
                try:
                    instance = models.Plan.objects.get(id=object_id)
                except ObjectDoesNotExist:
                    raise Http404
                extra_context = extra_context or {}
                extra_context['is_popup'] = True
                self.change_form_template = 'admin/ticket/change_form_iframe.html'
        try:
            return super(PlanAdmin, self).change_view(
                request, object_id, form_url, extra_context)
        except ticket_forms.ForbiddenException:
            return HttpResponseForbidden(render_to_string('jmb/forbidden.html'))

        '''
         form.fields["workers"].choices = self.get_all_workers(request_dict['ticket'])
                extraworkers = self.get_all_extraworkers(instance.ticket.id, instance.workers.all())
                form = PlanAdmin.form(instance=instance, initial={"extraworkers": extraworkers})
                form.fields["workers"].choices = self.get_all_workers(instance.ticket.id)
         '''

    def response_change(self, request, obj):
        jpopup_param = request.GET.get('jpopup', False)
        if jpopup_param:
            return self.response_post_save_change(request, obj)
        else:
            return super(PlanAdmin, self).response_change(request, obj)

    def delete_view(self, request, object_id, extra_context=None):
        if request.method == 'DELETE':
            try:
                instance = models.Plan.objects.get(id=object_id)
                instance.delete()
            except ObjectDoesNotExist:
                raise Http404
            response = HttpResponse('', content_type="application/json", status=200)
        else:
            response = super(PlanAdmin, self).delete_view(request, object_id, extra_context=None)
        return response

    def changelist_view(self, request, extra_context=None):
        opts = self.model._meta
        app_label = opts.app_label

        self.change_list_template = [
            'admin/%s/%s/change_list.html' % (app_label, opts.object_name.lower()),
            'admin/%s/change_list.html' % app_label,
            'admin/change_list.html'
        ]

        json_param = request.GET.get('_json', False)
        if json_param:
            qs = super(PlanAdmin, self).get_changelist_queryset(request)
            qs = qs.select_related('ticket', 'ticket__project', 'ticket__project__organization')
            # field_param = request.GET.get('field', False)
            # if field_param:
            #    qs.select_related('workers')
            # results = [ob.as_json() for ob in qs.all()]
            # return HttpResponse(json.dumps(results), content_type="application/json")
            results = serializers.serialize("json", qs.all(), extras=('label',),
                                            use_natural_keys=True)
            return HttpResponse(results, content_type="application/json")
        else:
            response = super(PlanAdmin, self).changelist_view(request, extra_context)
        return response

    def add_view(self, request, form_url='', extra_context=None):

        opts = self.model._meta
        app_label = opts.app_label

        self.add_form_template = [
            'admin/%s/%s/change_form.html' % (app_label, opts.object_name.lower()),
            'admin/%s/change_form.html' % app_label,
            'admin/change_form.html'
        ]

        json_param = request.GET.get('_json', False)
        jpopup_param = request.GET.get('jpopup', False)

        if request.method == 'POST':
            if jpopup_param:
                extra_context = extra_context or {}
                extra_context['is_popup'] = True
                self.add_form_template = 'admin/ticket/change_form_iframe.html'

        if request.method == 'GET':
            if jpopup_param:
                extra_context = extra_context or {}
                extra_context['is_popup'] = True
                '''
                form = PlanAdmin.form(initial=request_dict)
                form.fields["workers"].choices = self.get_all_workers(request_dict['ticket'])
                '''
                self.add_form_template = 'admin/ticket/change_form_iframe.html'
        try:
            return super(PlanAdmin, self).add_view(request, form_url, extra_context)
        except ticket_forms.ForbiddenException:
            return HttpResponseForbidden(render_to_string('jmb/forbidden.html'))

    def response_needs_to_close_iframe(self, request):
        return (
            request.POST.get("_json", False) or
            request.POST.get("_saveasnew", False) or
            request.POST.get("_json_continue", False)
            #  request.POST.get("_popup", False)
        )

    def response_add(self, request, obj, post_url_continue='..'):

        if request.POST.get('closeticket', False):
            ticket = obj.ticket
            ticket.status = 0
            ticket.save()

        if self.response_needs_to_close_iframe(request):
            method = '_json_continue' if '_json_continue' in request.POST else '_json'
            if request.GET.get("_refresh"):
                return HttpResponseRedirect(reverse('admin:ticket_ticket_json', args=[obj.ticket.pk]) + "?_refresh=1&_method=" + method)
            return HttpResponseRedirect(reverse('admin:ticket_plan_iframe', args=[obj.id, method]))
        return super(PlanAdmin, self).response_add(request, obj, post_url_continue)

    def get_form(self, request, obj=None, **kwargs):
        get = request.GET.copy()
        date_begin_initial = request.GET.get("date_begin", False)
        date_end_initial = request.GET.get("date_end", False)
        if date_begin_initial:
            get['date_begin'] = datetime.datetime.strptime(date_begin_initial, '%Y-%m-%d %H:%M:%S')
        if date_end_initial:
            get['date_end'] = datetime.datetime.strptime(date_end_initial, '%Y-%m-%d %H:%M:%S')
        request.GET = get
        form = super(PlanAdmin, self).get_form(request, obj, **kwargs)
        return form

    def get_all_workers(self, id):
        workers = models.TicketProject.objects.get(tickets__id=id).staff.all()
        for worker in workers:
            yield worker.id, worker.get_full_name()

    def get_all_extraworkers(self, id, selected):
        workers = models.TicketProject.objects.get(tickets__id=id).staff.all()
        extra = list()
        for worker in selected:
            if not worker in workers:
                extra.append(worker.id)
        return extra

    def only_result_list_view(self, request, extra_context=None):
        opts = self.model._meta
        app_label = opts.app_label

        self.change_list_template = [
            'admin/%s/%s/change_list.html' % (app_label, opts.object_name.lower()),
            'admin/%s/change_list.html' % app_label,
            'admin/change_list.html'
        ]
        self.change_list_template = ('admin/%s/only_result_list.html' %
                                     (app_label))

        return super(PlanAdmin, self).changelist_view(request, extra_context)

admin.site.register(models.Plan, PlanAdmin)
register_inline(PlanAjaxInline)
