# -*- coding: utf-8 -*-
"""
ajax module for jmb.ticket
"""

from dajax.core import Dajax
from dajaxice.decorators import dajaxice_register
from django.core.exceptions import ObjectDoesNotExist
from django.utils.translation import ugettext as _
from django.db.models import Q

from jmb.ticket import utils
from jmb.ticket.models import Organization, Contact
from jmb.ticket.models import TicketProject, Ticket

@dajaxice_register
def on_select_organization(request, *args, **kwargs):
    dajax = Dajax()
    options = "<option value >%s</option>" % ("-" * 9)
    dajax.assign('#id_project', 'innerHTML', options)
    dajax.assign('#id_submitter', 'innerHTML', options)
    dajax.assign('#id_assigned_by', 'innerHTML', options)
    dajax.assign('#id_assigned_to', 'innerHTML', options)
    user, contact = utils.get_current_contact()

    try:
        if contact:
            organizations = contact.ticket_organizations
            organization = organizations.get(id=kwargs['id_organization'])
            projects = contact.get_organization_ticketprojects(organization)

        elif user.is_superuser:
            organizations = Organization.customers_owners.filter(status=1)

            organization = organizations.get(id=kwargs['id_organization'])
            projects = organization.ticketprojects

        else:
            return dajax.json()

    except ObjectDoesNotExist:
        return dajax.json()

    # PROJECT SELECT
    for project in projects:
        options += "<option value='%s'>%s</option>" % (project.id, str(project))
    dajax.assign('#id_project', 'innerHTML', options)

    return dajax.json()

@dajaxice_register
def on_select_project(request, *args, **kwargs):
    dajax = Dajax()
    options = "<option>%s</option>" % ("-"*9)
    dajax.assign('#id_submitter', 'innerHTML', options)
    dajax.assign('#id_assigned_by', 'innerHTML', options)
    dajax.assign('#id_assigned_to', 'innerHTML', "")
    user, contact = utils.get_current_contact()

    empty_contact = Contact.objects.none()
    assigned_bys = empty_contact
    assigned_tos = empty_contact
    submitters = empty_contact

    #TODO: gestire superuser
    try:
        if user.is_superuser:
            organizations = Organization.customers_owners.filter(status=1)
            organization = organizations.get(id=kwargs['id_organization'])
            projects = organization.ticketprojects
            project = projects.get(id=kwargs['id_project'])
            assigned_bys = project.all_managers.qs
            assigned_tos = project.all_staff.qs
            submitters = project.submitters.qs

        elif contact:
            organizations = contact.ticket_organizations
            organization = organizations.get(id=kwargs['id_organization'])
            projects = contact.get_organization_ticketprojects(organization)
            project = projects.get(id=kwargs['id_project'])

            ticket_role = contact.get_role(organization, project)

            if ticket_role and ticket_role == "manager":
                assigned_bys = project.all_managers.qs
                assigned_tos = project.all_staff.qs
                submitters = project.submitters.qs

            elif ticket_role and ticket_role == "staff":
                submitters = project.submitters.qs

            elif ticket_role and ticket_role == "customer":
                submitters = project.submitters.qs

            else:
                submitters = AllSet([contact]).qs

        else:
            return dajax.json()

    except ObjectDoesNotExist:
        return dajax.json()

    # ASSIGNED_BY SELECT
    options = '<option value="">%s</option>' % ("-"*9)
    for assigned_by in assigned_bys:
        options += "<option value='%s' %s>%s</option>" % (
            assigned_by.id,
            "",
            assigned_by
        )
    dajax.assign('#id_assigned_by', 'innerHTML', options)

    # ASSIGNED_TO SELECT
    options = ""
    for assigned_to in assigned_tos:
        options += "<option value='%s' %s>%s</option>" % (
            assigned_to.id,
            "",
            str(assigned_to)
        )
    dajax.assign('#id_assigned_to', 'innerHTML', options)

    # SUBMITTER SELECT
    options = ""
    for submitter in submitters:
        options += "<option value='%s' %s>%s</option>" % (
            submitter.id,
            "selected" if contact and (submitter.id == contact.id) else "",
            #          "", TODO: SOLO PER ADD
            str(submitter)
        )
    dajax.assign('#id_submitter', 'innerHTML', options)

    return dajax.json()


@dajaxice_register
def on_select_ticket(request, *args, **kwargs):
    dajax = Dajax()
    options = "<option>%s</option>" % ("-"*9)
    dajax.assign('#id_worker', 'innerHTML', options)

    try:
        ticket = Ticket.objects.get(id=kwargs['id_ticket'])
    except ObjectDoesNotExist:
        return dajax.json()

    for worker in ticket.assigned_to.all():
        options += "<option value='%s'>%s</option>" % (worker.id, str(worker))

    dajax.assign('#id_worker', 'innerHTML', options)
    return dajax.json()
