# -*- coding: utf-8 -*-
import autocomplete_light
from django.utils.translation import ugettext_lazy as _

from . import models
from jmb.organization.models import OrganizationAddress
from jmb.core.utils.autocomplete import DynamicAutocompleteModelBase

class TicketAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['title', 'project__name', 'project__organization__name']
    choices = models.Ticket.objects

class ContactsEmailAutocomplete(autocomplete_light.AutocompleteModelBase):
    search_fields = ['first_name', 'email',
                     'last_name', 'organization__name']
    choices = models.Contact.objects.exclude(email__isnull=True).exclude(email__exact='')
    model = models.Contact

class ProjectOrganizationAddress(DynamicAutocompleteModelBase):
    search_fields = ['name']
    choices = models.OrganizationAddress.objects
    autocomplete_js_attributes = {
        'minimum_characters': 0,
        'placeholder': _('Address'),
    }
    attrs = autocomplete_js_attributes
    attrs.update({
        'data-autocomplete-minimum-characters': 0,
    })
    model = models.OrganizationAddress

    dependency_map = {
        'organization_id': '#id_organization',
    }


class OrganizationAddress(autocomplete_light.AutocompleteModelBase):
    search_fields = ['name', 'organization__name']
    choices = OrganizationAddress.objects
    model = models.OrganizationAddress

    def choice_label(self, choice):

        try:
            organization = " | " + unicode(choice.organization)
        except AttributeError:
            organization = ""

        return unicode(choice) + organization


class TicketProjectAutocomplete(DynamicAutocompleteModelBase):
    search_fields = ['name']
    choices = models.TicketProject.objects
    model = models.OrganizationAddress
    attrs = {
        'data-autocomplete-minimum-characters': 0,
        'placeholder': _('Project'),
    }
    dependency_map = {
        'organization_id': '#id_organization',
    }


autocomplete_light.register(OrganizationAddress, name="OrganizationAddress")
autocomplete_light.register(ProjectOrganizationAddress, name="ProjectOrganizationAddress")
autocomplete_light.register(TicketProjectAutocomplete, name="TicketProject")
autocomplete_light.register(TicketAutocomplete)
autocomplete_light.register(ContactsEmailAutocomplete, name='ContactsEmailAutocomplete')
