# -*- coding: utf-8 -*-
import datetime

from django.utils.translation import ugettext_lazy as _
import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard
from . import models

class DefaultDashboard(modules.Group):

    def __init__(self, **kwargs):
        today = datetime.date.today()
        kwargs = {
            'title': "Ticket",
            'display': "tabs",
            'children': [
                Models(),
                OtherModels(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)

class TicketDashboard(modules.Group):

    def __init__(self, **kwargs):
        today = datetime.date.today()
        kwargs = {
            'title': "Ticket",
            'display': "tabs",
            'children': [
                Models(),
                OtherModels(),
            ]
        }
        super(TicketDashboard, self).__init__(**kwargs)

class Models(modules.ModelList):

    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Main Models"),
            'models': (
                'jmb.ticket.models.Ticket',
                'jmb.ticket.models.TicketAssistance',
            ),
        }
        super(Models, self).__init__(**kwargs)

class OtherModels(modules.ModelList):

    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Others"),
            'models': (
                'jmb.ticket.models.Typology',
                'jmb.ticket.models.Category',
                'jmb.ticket.models.TicketProject',
                'jmb.ticket.models.Priority',
                'jmb.ticket.models.TypologyTranslation',
                'jmb.ticket.models.CategoryTranslation',
                'jmb.ticket.models.TicketPerm',
            ),
        }
        super(OtherModels, self).__init__(**kwargs)

class DefaultAppDashboard(AppIndexDashboard):

    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin
jmb_dashboard.register_group(TicketDashboard, 'jmb.ticket')
# Used in /admin/Ticket
admin_tools.dashboard.register(DefaultAppDashboard, 'jmb.ticket')
