# coding: utf-8
"""
.. _close_ticket_nºplans:

Close ticket w/o any plans
=============================

Command per chiudere tutti i ticket che non abbiano alcun plan

  dj sample

:-d: variabile Booleana per cancellare il messaggi una volta recuperati
:-l: variabile Numero per limitare il numero di messaggi recuperare
:-v: variabile Booleana per visualizzare i print
:-b, --backup: backup messages in
"""


import re
import os
import sys
import email
import tempfile
import datetime

from django.core.mail.message import EmailMessage
from django.core.management.base import BaseCommand
from django.conf import settings
from django.core import mail

from optparse import make_option

from jmb.ticket import models
from jmb.core import conf

class Command(BaseCommand):

    """Get all messages from configured Host
    """
    help = """close all tickets that have to_be_planned="0" and no pending plan"""

    option_list = BaseCommand.option_list + (
        make_option('-r', '--report', action='store_true', default=False,
                    help="Report and don't really do anything"),
        make_option('-D', '--debug', action='store_true', default=False,
                    dest='debug_message', help='Debug '),
        make_option('-l', '--limit', dest='limit', help='Limit Messages', default=1000),
        make_option('-f', '--file', dest='filename', help='Read file in argument', default=None),
        make_option('--pop', action='store_true', help='Retrieve using pop', default=False),
        make_option('-b', '--backup', action='store_true', dest='backup',
                    help='Keep a backup of retrieved email in ...',),
    )

    output_transaction = True

    def handle(self, *args, **options):
        conf.set_interactive_user()
        limit = options.get('limit')
        qs = models.Ticket.objects.filter(
            status=1,
            to_be_planned=0,
        ).exclude(priority__priority=20)
        qs_to_be_closed = qs.exclude(plans__date_begin__gte=datetime.date.today())
        count = qs.count()
        if options.get('report'):
            print("Ticket da chiudere: {0}/{1}".format(qs_to_be_closed.count(), count))
        else:
            closed = qs_to_be_closed.update(status=0)
            print("Ticket chiusi: {0}".format(closed))
