# coding: utf-8
"""
.. _ticket-attachment:

Save attachments in mail
========================


setup
-----

In ``master.cf``::

  ticket unix  -       n       n       -       -       pipe
          flags=FR user=mail:mail
          argv=sudo -u www-data /home/www/office.cogema.it/bin/django ticket_attachment -t ${user} 

che richiedere in ``sudoers``::

  mail   ALL= (www-data) NOPASSWD: /home/www/office.cogema.it/bin/django

  
in ``main.cf``::

  transport_maps =  hash:/etc/postfix/transport

in ``/etc/postfix/transport``::
  
   ticket.local  ticket:

seguito da postmap /etc/postfix/transport

Command per utilizzo::

  dj 

:-t: ticket the recipient of the email
:-f: filename. When testing email will be read from filesystem rather than stdin
:-v: 0,1,2
"""


import re
import os
import sys
import email
import tempfile
import datetime

from django.core.mail.message import EmailMessage
from django.core.management.base import BaseCommand
from django.conf import settings
from django.core import mail

from optparse import make_option

from jmb.ticket import utils

class Command(BaseCommand):

    """Get all messages from configured Host
    """
    help = 'Parses an email and stores the attached document. Recipient is the id of the ticket'

    option_list = BaseCommand.option_list + (
        make_option('-D', '--debug', action='store_true', default=False,
                    dest='debug_message', help='Debug '),
        make_option('-f', '--file', dest='filename', help='Read file in argument', default=None),
        make_option('-t', '--ticket', dest='ticket', help='The ticket', default=None),
    )

    output_transaction = True

    def handle(self, *args, **options):
        ticket = options['ticket']
        if options['filename']:
            utils.parse_email_and_save_attachments(ticket, filename=options['filename'])
        else:
            utils.parse_email_and_save_attachments(ticket, txt=sys.stdin.read())
