# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import datetime
from django.conf import settings
import jmb.core.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('project', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('i18n', '__first__'),
        ('organization', '0002_auto_20160705_2208'),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('name', models.CharField(max_length=30, verbose_name='Name')),
                ('code', models.CharField(max_length=6, null=True, verbose_name='Code', blank=True)),
                ('description', jmb.core.db.fields.HTMLFieldTinyMCE(null=True, verbose_name='Description')),
                ('creator', models.ForeignKey(related_name='ticket_category_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='ticket_category_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'Category',
                'verbose_name_plural': 'Categories',
            },
        ),
        migrations.CreateModel(
            name='CategoryTranslation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=30, verbose_name='Name')),
                ('category', models.ForeignKey(related_name='translations', to='ticket.Category')),
                ('language', models.ForeignKey(related_name='ticket_categorytranslation_translations', verbose_name='language', to='i18n.Language', help_text='language')),
            ],
            options={
                'verbose_name': 'Translation',
                'verbose_name_plural': 'Translations',
            },
        ),
        migrations.CreateModel(
            name='Log',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('field', models.CharField(max_length=100, verbose_name='Field')),
                ('old_value', models.TextField(verbose_name='Old Value')),
                ('new_value', models.TextField(verbose_name='New Value')),
                ('creator', models.ForeignKey(related_name='ticket_log_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='ticket_log_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'ticket log',
                'verbose_name_plural': 'ticket logs',
            },
        ),
        migrations.CreateModel(
            name='Plan',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('date_begin', models.DateTimeField(db_index=True, null=True, verbose_name='date begin', blank=True)),
                ('date_end', models.DateTimeField(db_index=True, null=True, verbose_name='date end', blank=True)),
                ('description', jmb.core.db.fields.HTMLFieldTinyMCE(null=True, verbose_name='Job Description', blank=True)),
                ('status', models.IntegerField(default=1, help_text=None, verbose_name='Status', choices=[(0, b'closed'), (1, b'open')])),
                ('address', models.ForeignKey(verbose_name='Address', blank=True, to='organization.OrganizationAddress', null=True)),
                ('creator', models.ForeignKey(related_name='ticket_plan_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='ticket_plan_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'plan ticket',
                'verbose_name_plural': 'plans ticket',
                'permissions': (('can_list_plan', 'Can list ticket plans'), ('can_list_all_plan', 'Can list all ticket plans'), ('can_list_own_plan', 'Can list own ticket plans'), ('can_modify_all_plan', 'Can modify all ticket plans')),
            },
        ),
        migrations.CreateModel(
            name='Priority',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('name', models.CharField(max_length=100, verbose_name='Name')),
                ('priority', models.IntegerField(unique=True, verbose_name='Priority')),
                ('color', models.CharField(max_length=100, verbose_name='Color')),
                ('color_text', models.CharField(max_length=100, verbose_name='Color Text')),
                ('creator', models.ForeignKey(related_name='ticket_priority_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='ticket_priority_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'ordering': ['priority'],
                'verbose_name': 'Priority',
                'verbose_name_plural': 'Priority',
            },
        ),
        migrations.CreateModel(
            name='Ticket',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, help_text=None, verbose_name='Status', choices=[(0, b'closed'), (1, b'open')])),
                ('progress_status', models.IntegerField(default=1, help_text=None, null=True, verbose_name='Progress Status', choices=[(1, 'to be assigned'), (2, 'standby'), (3, 'waiting for input'), (4, 'not repeatable'), (5, "won't fix"), (6, 'working'), (7, 'assigned'), (8, 'to discuss')])),
                ('title', models.CharField(max_length=100, verbose_name='Title')),
                ('keywords', models.CharField(help_text=b'keywords to categorize the ticket', max_length=150, null=True, verbose_name='Keywords', blank=True)),
                ('description', jmb.core.db.fields.HTMLFieldTinyMCE(verbose_name='Description')),
                ('duration', models.IntegerField(null=True, verbose_name='Duration', blank=True)),
                ('deadline', models.DateField(null=True, verbose_name='Deadline', blank=True)),
                ('triggerline', models.DateField(default=datetime.date.today, null=True, verbose_name='Triggerline', blank=True)),
                ('note', models.TextField(null=True, verbose_name='Note', blank=True)),
                ('public', models.BooleanField(default=False, help_text='Customers will have visibility of this ticket', verbose_name='Visible by customer')),
                ('to_be_planned', models.BooleanField(default=True, help_text='If True the ticket will appear in the ticket board', verbose_name='To be planned')),
                ('address', models.ForeignKey(related_name='tickets', verbose_name='Address', blank=True, to='organization.OrganizationAddress', null=True)),
            ],
            options={
                'verbose_name': 'Ticket',
                'verbose_name_plural': 'Tickets',
                'permissions': (('can_view_tickets', 'Can view tickets'), ('can_reopen_tickets', 'Can reopen tickets'), ('list_all_tickets', 'Can list all tickets'), ('list_own_contact_tickets', 'Can list own contact tickets'), ('list_own_organization_tickets', 'Can list own organization tickets')),
            },
        ),
        migrations.CreateModel(
            name='TicketAssistance',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('date_begin', models.DateTimeField(db_index=True, null=True, verbose_name='date begin', blank=True)),
                ('date_end', models.DateTimeField(db_index=True, null=True, verbose_name='date end', blank=True)),
                ('work_duration', models.IntegerField(help_text='In Minutes', null=True, verbose_name='work duration', blank=True)),
                ('job_description', jmb.core.db.fields.HTMLFieldTinyMCE(null=True, verbose_name='Job Description', blank=True)),
                ('extra_duration', models.IntegerField(help_text='In Minutes', null=True, verbose_name='extra duration', blank=True)),
                ('travel_duration', models.IntegerField(help_text='In Minutes', null=True, verbose_name='travel duration', blank=True)),
                ('kilometers', models.IntegerField(null=True, verbose_name='kilometers', blank=True)),
                ('overnight_stay', models.BooleanField(default=False, verbose_name='overnight stay')),
                ('carrying', models.CharField(choices=[(b'com', 'company'), (b'own', 'own'), (b'cus', 'customer'), (b'pub', 'public'), (b'oth', 'other')], max_length=3, blank=True, null=True, verbose_name='carrying', db_index=True)),
                ('pay_exit', models.NullBooleanField(default=False, verbose_name='pay exit', db_index=True)),
                ('procedure', models.BooleanField(default=False, db_index=True, verbose_name='Ordered')),
                ('creator', models.ForeignKey(related_name='ticket_ticketassistance_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='ticket_ticketassistance_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('ticket', models.ForeignKey(related_name='assistances', verbose_name='ticket', to='ticket.Ticket')),
            ],
            options={
                'verbose_name': 'assistance ticket',
                'verbose_name_plural': 'assistances ticket',
                'permissions': (('can_view_ticketassistances', 'Can view ticket assistances'), ('list_all_ticketassistances', 'Can list all ticket assistances'), ('list_own_ticketassistances', 'Can list own ticket assistances'), ('can_modify_all_ticketassistances', 'Can modify all ticket assistances')),
            },
        ),
        migrations.CreateModel(
            name='TicketAttachment',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('file', models.FileField(upload_to=b'tickets/%Y/%m/%W/', verbose_name='File')),
                ('description', models.CharField(max_length=255, null=True, verbose_name='Description', blank=True)),
                ('creator', models.ForeignKey(related_name='ticket_ticketattachment_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='ticket_ticketattachment_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('ticket', models.ForeignKey(related_name='attachments', verbose_name='Ticket', to='ticket.Ticket')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='TicketPerm',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('project_manager', models.BooleanField(default=False, help_text='THis contact is managers of all projects', verbose_name='Contact is manager of all projects')),
                ('project_staff', models.BooleanField(default=False, help_text='Contact is staff of all tickets', verbose_name='Contact is staff of all tickets')),
            ],
            options={
                'verbose_name': 'ticket permission',
                'verbose_name_plural': 'ticket permission',
            },
        ),
        migrations.CreateModel(
            name='TicketProject',
            fields=[
                ('project_ptr', models.OneToOneField(parent_link=True, auto_created=True, primary_key=True, serialize=False, to='project.Project')),
                ('assistance_email', models.EmailField(max_length=254, null=True, verbose_name='Assistance Email', blank=True)),
                ('icon', models.ImageField(upload_to=b'tickets/icon/', null=True, verbose_name='Icon', blank=True)),
                ('address', models.ForeignKey(related_name='ticket_projects', verbose_name='Address', blank=True, to='organization.OrganizationAddress', null=True)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name': 'Project',
                'verbose_name_plural': 'Projects',
                'permissions': (('can_view_ticket_projects', 'Can view ticket projects'), ('list_all_ticket_projects', 'Can list all ticket projects'), ('ticket_site_manager', 'Is site manager'), ('ticket_site_staff', 'Is site staff')),
            },
            bases=('project.project',),
        ),
        migrations.CreateModel(
            name='Typology',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('date_create', models.DateTimeField(null=True, verbose_name='date create', blank=True)),
                ('date_last_modify', models.DateTimeField(null=True, verbose_name='date last modify', blank=True)),
                ('status', models.IntegerField(default=1, null=True, verbose_name='Status', choices=[(0, 'Inactive'), (1, 'Active')])),
                ('name', models.CharField(max_length=30, verbose_name='Name')),
                ('description', jmb.core.db.fields.HTMLFieldTinyMCE(null=True, verbose_name='Description')),
                ('creator', models.ForeignKey(related_name='ticket_typology_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
                ('last_modifier', models.ForeignKey(related_name='ticket_typology_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True)),
            ],
            options={
                'verbose_name': 'Typology',
                'verbose_name_plural': 'Typologies',
            },
        ),
        migrations.CreateModel(
            name='TypologyTranslation',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=30, verbose_name='Name')),
                ('language', models.ForeignKey(related_name='ticket_typologytranslation_translations', verbose_name='language', to='i18n.Language', help_text='language')),
                ('typology', models.ForeignKey(related_name='translations', to='ticket.Typology')),
            ],
            options={
                'verbose_name': 'Translation',
                'verbose_name_plural': 'Translations',
            },
        ),
        migrations.CreateModel(
            name='Contact',
            fields=[
            ],
            options={
                'proxy': True,
            },
            bases=('organization.contact',),
        ),
        migrations.CreateModel(
            name='Organization',
            fields=[
            ],
            options={
                'proxy': True,
            },
            bases=('organization.organization',),
        ),
        migrations.AddField(
            model_name='ticketproject',
            name='customers',
            field=models.ManyToManyField(related_name='visible_ticketprojects', verbose_name='Customers', to='ticket.Contact'),
        ),
        migrations.AddField(
            model_name='ticketproject',
            name='managers',
            field=models.ManyToManyField(related_name='managed_ticketprojects', verbose_name='Managers', to='ticket.Contact'),
        ),
        migrations.AddField(
            model_name='ticketproject',
            name='staff',
            field=models.ManyToManyField(related_name='assigned_ticketprojects', verbose_name='Staff', to='ticket.Contact'),
        ),
        migrations.AddField(
            model_name='ticketperm',
            name='contact',
            field=models.OneToOneField(related_name='ticketperm', verbose_name='Contact', to='ticket.Contact'),
        ),
        migrations.AddField(
            model_name='ticketperm',
            name='creator',
            field=models.ForeignKey(related_name='ticket_ticketperm_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='ticketperm',
            name='last_modifier',
            field=models.ForeignKey(related_name='ticket_ticketperm_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='ticketassistance',
            name='worker',
            field=models.ForeignKey(related_name='assistances', verbose_name='worker', to='ticket.Contact'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='assigned_by',
            field=models.ForeignKey(related_name='tickets_assigned_by_me', verbose_name='Assigned by', blank=True, to='ticket.Contact', null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='assigned_to',
            field=models.ManyToManyField(related_name='tickets_assigned_to_me', db_index=True, verbose_name='Assigned to', to='ticket.Contact', blank=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='category',
            field=models.ForeignKey(related_name='tickets', verbose_name='Category', blank=True, to='ticket.Category', null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='creator',
            field=models.ForeignKey(related_name='ticket_ticket_creator', verbose_name='creator', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='last_modifier',
            field=models.ForeignKey(related_name='ticket_ticket_last_modifier', verbose_name='last modifier', blank=True, to=settings.AUTH_USER_MODEL, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='organization',
            field=models.ForeignKey(related_name='tickets', verbose_name='Organization', blank=True, to='ticket.Organization', null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='priority',
            field=models.ForeignKey(related_name='tickets', default=1, verbose_name='Priority', to_field=b'priority', to='ticket.Priority'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='project',
            field=models.ForeignKey(related_name='tickets', verbose_name='Project', blank=True, to='ticket.TicketProject', null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='submitter',
            field=models.ForeignKey(related_name='tickets_summitted', verbose_name='Submitter', to='ticket.Contact'),
        ),
        migrations.AddField(
            model_name='ticket',
            name='typology',
            field=models.ForeignKey(related_name='tickets', verbose_name='Typology', blank=True, to='ticket.Typology', null=True),
        ),
        migrations.AddField(
            model_name='plan',
            name='priority',
            field=models.ForeignKey(related_name='plans', verbose_name='Priority', to_field=b'priority', blank=True, to='ticket.Priority', null=True),
        ),
        migrations.AddField(
            model_name='plan',
            name='ticket',
            field=models.ForeignKey(related_name='plans', verbose_name='ticket', to='ticket.Ticket'),
        ),
        migrations.AddField(
            model_name='plan',
            name='workers',
            field=models.ManyToManyField(related_name='plans', db_index=True, verbose_name='workers', to='ticket.Contact', blank=True),
        ),
        migrations.AddField(
            model_name='log',
            name='ticket',
            field=models.ForeignKey(related_name='logs', verbose_name='Ticket', to='ticket.Ticket'),
        ),
        migrations.AlterUniqueTogether(
            name='typologytranslation',
            unique_together=set([('typology', 'language')]),
        ),
        migrations.AlterUniqueTogether(
            name='categorytranslation',
            unique_together=set([('category', 'language')]),
        ),
    ]
