import copy
from django.core.mail import send_mail
from django_comments.signals import comment_was_posted
from django.utils.translation import ugettext as _
from django.db.models.signals import post_save, pre_save

from django.conf import settings
from jmb.core.shortcuts import render_to_string
from jmb.core.middleware.thread_local import get_request, get_current_user

from jmb.ticket.email_communication import TicketEmail
from jmb.ticket.models import TicketProject, Ticket, Plan
from jmb.ticket import utils
from jmb.ticket.admin.forms import TicketAdminForm

class CommentEmail(TicketEmail):

    def __init__(self, ticket, comment):
        self.obj = ticket
        self.subject_msg = "%s[COMMENTO][%s] Ticket %s" % (
            settings.TICKET_SUBJECT_PREFIX, ticket.organization, ticket.id)
        if ticket.project:
            self.subject_msg = "%s[#%s][%s][COMMENTO] Ticket %s - Progetto : %s" % (
                settings.TICKET_SUBJECT_PREFIX, ticket.project.id,
                ticket.organization, ticket.id, ticket.project)
        else:
            self.subject_msg += " - Progetto Generico"

        self.recipient_list = self.get_recipient_list(ticket)
        self.body_msg = self.html_body_msg = render_to_string(
            "ticket/email/new_comment.html", ticket=ticket, comment=comment,
        )
        self.from_mail = ticket.get_from_email()

def send_comment_email(sender, comment, request, **kwargs):

    if settings.TICKET_SEND_EMAIL:
        ct = comment.content_type
        app_name = ct.name

        if app_name != 'Ticket':
            return

        ticket = ct.model_class().objects.get(pk=comment.object_pk)
        comment_email = CommentEmail(ticket, comment)
        comment_email.send()


def save_old_ticket(sender, **kwargs):
    "Save the old instance of the ticket to be able get differences in the mail"
    obj = kwargs['instance']
    try:
        obj._old_obj = Ticket.objects.get(pk=obj.id)
    except Ticket.DoesNotExist:
        obj._old_obj = None

def send_ticket_save_email(sender, **kwargs):
    obj = kwargs['instance']
    created = kwargs['created']
    request = get_request()
    user, contact = utils.get_current_contact()

    TicketEmail(request, obj, created).send()


def close_ticket_after_plan_save(sender, **kwargs):
    obj = kwargs['instance']
    created = kwargs['created']
    request = get_request()
    close_ticket = request.POST.get("close_ticket", False)
    if close_ticket:
        obj.ticket.status = 0
        obj.ticket.save()


def close_plans_after_ticket_save(sender, **kwargs):
    obj = kwargs['instance']
    created = kwargs['created']
    request = get_request()
    if obj.status == 0:
        obj.plans.all().update(status=0)


if settings.TICKET_SEND_EMAIL:
    comment_was_posted.connect(send_comment_email)
    post_save.connect(send_ticket_save_email, sender=Ticket)
    pre_save.connect(save_old_ticket, sender=Ticket)

post_save.connect(close_plans_after_ticket_save, sender=Ticket)
post_save.connect(close_ticket_after_plan_save, sender=Plan)
