from django.http import HttpResponse, HttpResponseRedirect, HttpResponseNotFound, HttpResponseForbidden, Http404
from django.shortcuts import get_object_or_404

from jmb.ticket.models import Ticket, TicketAssistance


def ticket_reopen(request, id):
    if not request.user.has_perm("ticket.change_ticket") and \
       not request.user.has_perm("ticket.reopen_ticket"):
        return HttpForbidden()

    ticket = get_object_or_404(Ticket, pk=id)

    if ticket.assigned_to.count():
        ticket.status = 7
    else:
        ticket.status = 1
    ticket.save()

    return HttpResponseRedirect(request.META['HTTP_REFERER'])


def ticket_assistances_list(request, id):
    """ Visualizza le assistenze relative ad un ticket """
    if not request.user.has_perm("ticket.view_ticketassistance"):
        return HttpForbidden()

    ticket = get_object_or_404(Ticket, pk=id)

    ta = TicketAssistance.ticket_assistances.filter(ticket=ticket).order_by('worker', '-date_begin')
    last_worker = None
    worker_ass = []
    for a in ta:
        if not last_worker:
            wa = WorkerAssistance()
            wa.worker = a.worker
            last_worker = a.worker

        if a.worker.user.username == last_worker.user.username:
            wa.assistances.append(a)
        else:
            worker_ass.append(wa)
            wa = WorkerAssistance()
            wa.worker = a.worker
            wa.assistances.append(a)

        last_worker = a.worker

    worker_ass.append(wa)

    return render_to_response('admin/ticket/ticket/ticket_assistances_list.html', ticket=ticket, worker_ass=worker_ass)


def ticketassistances_calendar_list(request):
    template_name = 'admin/ticket/ticketassistance/calendar.html'

    #day = date.today()
    #else:
    #day = date(2010,01,01)

    period = CalendarMonth()
    first_date = datetime(period.first_datetime_range.year,
                          period.first_datetime_range.month,
                          period.first_datetime_range.day, 0, 0, 0)
    last_date = datetime(period.last_datetime_range.year,
                         period.last_datetime_range.month,
                         period.last_datetime_range.day, 23, 59, 59)

    assistances = TicketAssistance.objects.filter(
        date_begin__gte=first_date, date_begin__lte=last_date
    ).order_by('worker', 'date_begin')

    for ass in assistances:
        period.add_event(ass)

    return render_to_response(template_name, period=period, app_label='ticket')
